pub struct EncodedPostBundleV1 {
pub header: EncodedPostBundleHeaderV1,
pub encoded_posts_bytes: Bytes,
}Fields
header: EncodedPostBundleHeaderV1encoded_posts_bytes: BytesImplementations
Sourceimpl EncodedPostBundleV1
impl EncodedPostBundleV1
pub fn to_bytes(&self) -> Result<Bytes>
pub fn from_bytes(bytes: Bytes, decode_body: bool) -> Result<Self>
Sourcepub fn verify(&self, base_id: &Id) -> Result<()>
pub fn verify(&self, base_id: &Id) -> Result<()>
Verifies that this bundle is legitimate enough to cache.
Checks:
- The bundle header is structurally valid and its signature verifies.
- The sum of
encoded_post_lengthsexactly spansencoded_posts_bytes, and the plaintextpost_idprefix of each slice matches the corresponding entry inencoded_post_ids. - Each post slice can be decrypted using
base_id, which also verifies the per-post signature and hash integrity.